@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib-Clitt
+   @project: HsPyLib-Clitt
    @package: clitt
       @file: __classpath__.py
    @created: Fri, 23 Dec 2022
@@ -10,7 +10,7 @@
       @site: "https://github.com/yorevs/hspylib")
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright 2023, HsPyLib team
 """
 
 from hspylib.core.metaclass.classpath import Classpath
