@@ -1,14 +1,12 @@
 # _*_ coding: utf-8 _*_
 #
-# hspylib-clitt v0.9.20
+# hspylib-clitt v0.9.43
 #
 # Package: main.clitt
 """Package initialization."""
 
 __all__ = [
-  '__classpath__', 
-  '__main__', 
   'addons', 
   'core'
 ]
-__version__ = '0.9.20'
+__version__ = '0.9.43'
