@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib
+   @project: HsPyLib-Clitt
    @package: clitt.addons.appman
       @file: appman.py
    @created: Tue, 4 May 2021
@@ -10,11 +10,11 @@
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright 2023, HsPyLib team
 """
-import os
-import stat
-import urllib3
+from clitt.addons.appman.appman_enums import AppExtension, AppType
+from clitt.core.tui.minput.input_validator import InputValidator
+from clitt.core.tui.minput.minput import MenuInput, minput
 from hspylib.core.enums.charset import Charset
 from hspylib.core.enums.http_code import HttpCode
 from hspylib.core.metaclass.singleton import Singleton
@@ -30,9 +30,9 @@ from hspylib.modules.fetch.fetch import get
 from textwrap import dedent
 from typing import List
 
-from clitt.addons.appman.appman_enums import AppExtension, AppType
-from clitt.core.tui.minput.input_validator import InputValidator
-from clitt.core.tui.minput.minput import MenuInput, minput
+import os
+import stat
+import urllib3
 
 HERE = get_path(__file__)
 
@@ -42,8 +42,7 @@ WELCOME_MESSAGE = f"My Application v{INITIAL_REVISION}"
 
 
 class AppManager(metaclass=Singleton):
-    """HSPyLib application manager that helps creating HSPyLib based applications and widgets.
-    """
+    """HsPyLib application manager that helps creating HsPyLib based applications and widgets."""
 
     # The directory containing all template files
     TEMPLATES = HERE / "templates"
@@ -65,8 +64,7 @@ class AppManager(metaclass=Singleton):
 
     @staticmethod
     def prompt() -> Namespace:
-        """Prompt for the application info.
-        """
+        """Prompt for the application info."""
         # fmt: off
         form_fields = MenuInput.builder() \
             .field() \
@@ -136,7 +134,7 @@ class AppManager(metaclass=Singleton):
         sysout(f"Successfully created the {app_type.value} {app_name}")
 
     def _create_app(self, app_name: str, app_ext: List[AppExtension]) -> None:
-        """Create a Simple HSPyLib application.
+        """Create a Simple HsPyLib application.
         :param app_name the application name.
         :param app_ext the application extensions (gradle, git, ...).
         """
@@ -149,7 +147,7 @@ class AppManager(metaclass=Singleton):
         self._apply_extensions(app_name, app_ext)
 
     def _create_qt_app(self, app_name: str, app_ext: List[AppExtension]) -> None:
-        """Create an HSPyLib QT application.
+        """Create an HsPyLib QT application.
         :param app_name the application name.
         :param app_ext the application extensions (gradle, git, ...).
         """
@@ -172,19 +170,20 @@ class AppManager(metaclass=Singleton):
         self._apply_extensions(app_name, app_ext)
 
     def _create_widget(self, app_name: str) -> None:
-        """Create an HSPyLib Widget application.
+        """Create an HsPyLib Widget application.
         :param app_name the application name.
         """
         widget_name = camelcase(app_name).replace("_", "").replace(" ", "")
         sysout(f"Widget: {widget_name}")
         self._mkfile(
             f"widget_{app_name.lower()}.py",
-            (self.TEMPLATES / "widget.py.tpl").read_text()
+            (self.TEMPLATES / "widget.py.tpl")
+            .read_text()
             .replace("_WIDGET_NAME_", f"{camelcase(app_name, upper=True)}"),
         )
 
     def _create_base_app_struct(self, app_name: str) -> None:
-        """Create a base HSPyLib application structure and files.
+        """Create a base HsPyLib application structure and files.
         :param app_name the application name.
         """
         self._mkdir()
@@ -255,7 +254,7 @@ class AppManager(metaclass=Singleton):
         """Initialize the as a gradle project.
         :param app_name the application name.
         """
-        sysout(f"Initializing \"{app_name}\" gradle project [press ENTER to continue] ...")
+        sysout(f'Initializing "{app_name}" gradle project [press ENTER to continue] ...')
         output, exit_code = Terminal.shell_exec(
             f"gradle init --project-name {app_name} --type basic --dsl groovy", cwd=self._app_dir
         )
@@ -283,8 +282,7 @@ class AppManager(metaclass=Singleton):
         return exit_code == ExitStatus.SUCCESS
 
     def _init_git(self) -> bool:
-        """Initialize a git repository for the project.
-        """
+        """Initialize a git repository for the project."""
         self._mkfile(".gitignore", (self.TEMPLATES / "gitignore.tpl").read_text())
         sysout("Initializing git repository ...")
         output, exit_code = Terminal.shell_exec("git init", cwd=self._app_dir)
@@ -292,14 +290,14 @@ class AppManager(metaclass=Singleton):
         if exit_code:
             sysout("Creating first commit")
             Terminal.shell_exec("git add .", cwd=self._app_dir)
-            output, exit_code = Terminal.shell_exec('git commit -m "First commit [@HSPyLib]"', cwd=self._app_dir)
+            output, exit_code = Terminal.shell_exec('git commit -m "First commit [@HsPyLib]"', cwd=self._app_dir)
             sysout(f"Git commit result: {exit_code}%EOL%{output}%EOL%")
 
         return exit_code == ExitStatus.SUCCESS
 
     def _download_gradle_ext(self, gradle_ext: str) -> None:
-        """Download a gradle extension from the HSPyLib repository.
-        :param gradle_ext the HSPyLib gradle extension to download.
+        """Download a gradle extension from the HsPyLib repository.
+        :param gradle_ext the HsPyLib gradle extension to download.
         """
         urllib3.disable_warnings()  # Disable this warning because we trust our project repo
         resp = get(f"https://raw.githubusercontent.com/yorevs/hspylib/master/gradle/{gradle_ext}")
