@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib
+   @project: HsPyLib-Clitt
    @package: clitt.addons.appman
       @file: appman_enums.py
    @created: Fri, 29 Jul 2022
@@ -10,15 +10,14 @@
       @site: "https://github.com/yorevs/hspylib")
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright 2023, HsPyLib team
 """
-
 from hspylib.core.enums.enumeration import Enumeration
+from typing import List
 
 
 class AppExtension(Enumeration):
-    """Appman available extensions.
-    """
+    """Appman available extensions."""
 
     # fmt: off
     GRADLE  = 'gradle'
@@ -27,11 +26,14 @@ class AppExtension(Enumeration):
 
 
 class AppType(Enumeration):
-    """Appman supported application types.
-    """
+    """Appman supported application types."""
 
     # fmt: off
     APP     = 'app'
     QT_APP  = 'qt-app'
     WIDGET  = 'widget'
     # fmt: on
+
+    @staticmethod
+    def choices() -> List[str]:
+        return AppType.values()
