@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib
+   @project: HsPyLib-Clitt
    @package: clitt.addons.widman
       @file: widget_entry.py
    @created: Fri, 04 Jun 2021
@@ -10,16 +10,15 @@
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright 2023, HsPyLib team
 """
-import os
-
 from hspylib.core.tools.text_tools import camelcase
 
+import os
+
 
 class WidgetEntry:
-    """Placeholder object for a HSPyLib::Widman Widget and details about it.
-    """
+    """Placeholder object for a HsPyLib::Widman Widget and details about it."""
 
     # fmt: off
     MODULE_PREFIX   = "widget_"
