@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib
+   @project: HsPyLib-Clitt
    @package: clitt.addons.widman.widgets
       @file: widget_free.py
    @created: Thu, 20 May 2021
@@ -10,9 +10,10 @@
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright 2023, HsPyLib team
 """
-import re
+from clitt.addons.widman.widget import Widget
+from clitt.core.icons.font_awesome.widget_icons import WidgetIcons
 from concurrent import futures
 from hspylib.core.tools.commons import human_readable_bytes, sysout
 from hspylib.modules.application.exit_status import ExitStatus
@@ -22,12 +23,11 @@ from hspylib.modules.cli.terminal import Terminal
 from textwrap import dedent
 from time import sleep
 
-from clitt.addons.widman.widget import Widget
-from clitt.core.icons.font_awesome.widget_icons import WidgetIcons
+import re
 
 
 class WidgetFree(Widget):
-    """HSPyLib Widget to Report current system memory usage"""
+    """HsPyLib Widget to Report current system memory usage"""
 
     # fmt: off
     WIDGET_ICON = WidgetIcons.CHIP
@@ -56,8 +56,7 @@ class WidgetFree(Widget):
     # pylint: disable=too-many-locals
     @staticmethod
     def _report_usage() -> bool:
-        """Display the memory usage for the cycle.
-        """
+        """Display the memory usage for the cycle."""
         ps, ec1 = Terminal.shell_exec("ps -caxm -orss,comm")  # Get process info
         vm, ec2 = Terminal.shell_exec("vm_stat")  # Grabbing memory characteristics
 
