@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib
+   @project: HsPyLib-Clitt
    @package: clitt.addons.widman.widgets
       @file: widget_punch.py
    @created: Thu, 20 Sep 2022
@@ -10,12 +10,11 @@
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright 2023, HsPyLib team
 """
-import argparse
-import os
-import re
-import sys
+from clitt.addons.widman.widget import Widget
+from clitt.addons.widman.widgets.widget_time_calc import WidgetTimeCalc
+from clitt.core.icons.font_awesome.widget_icons import WidgetIcons
 from hspylib.core.enums.charset import Charset
 from hspylib.core.tools.commons import syserr, sysout
 from hspylib.core.zoned_datetime import now
@@ -26,13 +25,14 @@ from hspylib.modules.cli.terminal import Terminal
 from textwrap import dedent
 from typing import List
 
-from clitt.addons.widman.widget import Widget
-from clitt.addons.widman.widgets.widget_time_calc import WidgetTimeCalc
-from clitt.core.icons.font_awesome.widget_icons import WidgetIcons
+import argparse
+import os
+import re
+import sys
 
 
 class WidgetPunch(Widget):
-    """HSPyLib Widget to Report current system memory usage"""
+    """HsPyLib Widget to Report current system memory usage"""
 
     # fmt: off
     WIDGET_ICON = WidgetIcons.PUNCH
@@ -82,7 +82,7 @@ class WidgetPunch(Widget):
             stamps += [daily_punches[1], "-", daily_punches[0], "+"] if n // 2 >= 1 else []  # Morning
             stamps += [daily_punches[3], "-", daily_punches[2], "+"] if n // 2 >= 2 else []  # Afternoon
             stamps += [daily_punches[5], "-", daily_punches[4]] if n // 2 >= 3 else []  # Evening
-            h, m, _ = WidgetTimeCalc.calc_time(stamps)
+            h, m, _ = WidgetTimeCalc.calc_time(*stamps)
             m = WidgetTimeCalc.to_decimal(m) if decimal else m
             return f"{'%GREEN%' if h >= 8 else '%RED%'}{h:02d}{'.' if decimal else ':'}{m:02d}%NC%"
 
@@ -100,7 +100,6 @@ class WidgetPunch(Widget):
         self._week_num = self.WEEK_STAMP
 
     def execute(self, *args) -> ExitStatus:
-
         # Create the current week punch file if it does not yet exist.
         if not os.path.exists(self.HHS_PUNCH_FILE):
             with open(self.HHS_PUNCH_FILE, "w", encoding=Charset.UTF_8.val) as f_punch:
@@ -190,8 +189,7 @@ class WidgetPunch(Widget):
         return punch_line
 
     def _do_the_punch(self) -> None:
-        """Punch the clock.
-        """
+        """Punch the clock."""
         with open(self.HHS_PUNCH_FILE, "w", encoding=Charset.UTF_8.val) as f_punch:
             if not self._today:  # Write the first punch of the day
                 self._today = f"{self.DATE_STAMP} => {self.TIME_STAMP}"
@@ -207,8 +205,7 @@ class WidgetPunch(Widget):
         sysout(f"{re.sub(self.DATE_STAMP, '%GREEN%Today%NC%', self._today)} ")
 
     def _list_punches(self) -> None:
-        """List all punches from the punch file.
-        """
+        """List all punches from the punch file."""
         total = 0, 0
         total_dec = 0, 0
         sysout(f"\n%WHITE%Week-{self._week_num:02d} Punches%NC%")
@@ -223,24 +220,22 @@ class WidgetPunch(Widget):
             daily_total_dec = self._daily_total(daily_punches, decimal=True)
             if n > 0 and n % 2 == 0:
                 sysout(f" {padding} : Subtotal = {daily_total} -> {daily_total_dec}%NC%")
-                total = WidgetTimeCalc.calc_time([f"{total[0]}:{total[1]}", "+", daily_total[-9:-4]])
+                total = WidgetTimeCalc.calc_time(f"{total[0]}:{total[1]}", "+", daily_total[-9:-4])
                 total_dec = total[0], WidgetTimeCalc.to_decimal(total[1])
             else:
                 sysout(f"{daily_total}%NC%")
         sysout("-" * 82)
-        bh, bm, _ = WidgetTimeCalc.calc_time([f"{total[0]}:{total[1]}", "-", "40:00"])
+        bh, bm, _ = WidgetTimeCalc.calc_time(f"{total[0]}:{total[1]}", "-", "40:00")
         balance = f"{'%BLUE%' if bh >= 0 else '%RED%'}{bh:02d}:{bm:02d}%NC%"
         totals = f"{total[0]:02d}:{total[1]:02d} -> {total_dec[0]:02d}.{total_dec[1]:02d}"
         sysout(f"%WHITE%Total: ({totals})  Balance: {balance}\n")
 
     def _edit_punches(self) -> None:
-        """Open the default system editor to edit punches.
-        """
+        """Open the default system editor to edit punches."""
         Terminal.open_file(self.HHS_PUNCH_FILE)
 
     def _reset_punches(self) -> None:
-        """Rename the punch file as a weekly punch file and reset current punch file.
-        """
+        """Rename the punch file as a weekly punch file and reset current punch file."""
         punch_dir = os.path.dirname(self.HHS_PUNCH_FILE)
         new_name = f"{punch_dir}/week-{self._week_num:02d}.punch"
         if os.path.exists(new_name):
