@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib
+   @project: HsPyLib-Clitt
    @package: clitt.addons.widman.widgets
       @file: widget_send_msg.py
    @created: Thu, 26 Aug 2017
@@ -10,11 +10,12 @@
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright 2023, HsPyLib team
 """
-import os
-import socket
-import threading
+from clitt.addons.widman.widget import Widget
+from clitt.core.icons.font_awesome.widget_icons import WidgetIcons
+from clitt.core.tui.minput.input_validator import InputValidator
+from clitt.core.tui.minput.minput import MenuInput, minput
 from hspylib.core.exception.exceptions import WidgetExecutionError
 from hspylib.core.tools.commons import hook_exit_signals, sysout
 from hspylib.modules.application.argparse.argument_parser import HSArgumentParser
@@ -24,14 +25,13 @@ from hspylib.modules.cli.keyboard import Keyboard
 from textwrap import dedent
 from time import sleep
 
-from clitt.addons.widman.widget import Widget
-from clitt.core.icons.font_awesome.widget_icons import WidgetIcons
-from clitt.core.tui.minput.input_validator import InputValidator
-from clitt.core.tui.minput.minput import MenuInput, minput
+import os
+import socket
+import threading
 
 
 class WidgetSendMsg(Widget):
-    """HSPyLib Widget to send TCP/UDP messages (multi-threaded)"""
+    """HsPyLib Widget to send TCP/UDP messages (multi-threaded)"""
 
     # fmt: off
     MAX_THREADS     = 1000
@@ -109,8 +109,7 @@ class WidgetSendMsg(Widget):
         return ExitStatus.SUCCESS
 
     def cleanup(self) -> None:
-        """Stops workers and close socket connection.
-        """
+        """Stops workers and close socket connection."""
         sysout("Terminating threads%NC%")
         self.is_alive = False
         if self.net_type == self.NET_TYPE_TCP:
@@ -118,8 +117,7 @@ class WidgetSendMsg(Widget):
             self.socket.close()
 
     def _prompt(self) -> bool:
-        """When no input is provided (e.g:. when executed from dashboard). Prompt the user for the info.
-        """
+        """When no input is provided (e.g:. when executed from dashboard). Prompt the user for the info."""
         # fmt: off
         form_fields = MenuInput.builder() \
             .field() \
@@ -219,8 +217,7 @@ class WidgetSendMsg(Widget):
         return bool(self._args)
 
     def _init_sockets(self) -> None:
-        """Initialize sockets.
-        """
+        """Initialize sockets."""
         if self.net_type == self.NET_TYPE_UDP:
             self.socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
         else:
@@ -232,8 +229,7 @@ class WidgetSendMsg(Widget):
                 raise WidgetExecutionError("Unable to initialize sockets") from err
 
     def _start_send(self) -> None:
-        """Start sending packets.
-        """
+        """Start sending packets."""
         thread_relief = 0.05
         self._init_sockets()
         sysout(
@@ -253,8 +249,7 @@ class WidgetSendMsg(Widget):
             sleep(2 * thread_relief)
 
     def _send_packet(self, thread_num: int) -> None:
-        """Send a packet.
-        """
+        """Send a packet."""
         lock = threading.Lock()
 
         while self.is_alive and self.packets <= 0 or self.counter <= self.packets:
