@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib
+   @project: HsPyLib-Clitt
    @package: clitt.core.icons.emojis
       @file: face_smiling.py
    @created: Tue, 4 May 2021
@@ -10,7 +10,7 @@
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright 2023, HsPyLib team
 """
 from clitt.core.icons.emojis.emojis import Emoji
 
