@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib
+   @project: HsPyLib-Clitt
    @package: clitt.core.icons.font_awesome
       @file: app_icons.py
    @created: Tue, 4 May 2021
@@ -10,11 +10,10 @@
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright 2023, HsPyLib team
 """
-from enum import auto
-
 from clitt.core.icons.font_awesome.awesome import Awesome
+from enum import auto
 
 
 # @composable
