@@ -1,6 +1,6 @@
 # _*_ coding: utf-8 _*_
 #
-# hspylib-clitt v0.9.20
+# hspylib-clitt v0.9.43
 #
 # Package: main.clitt.core.tui
 """Package initialization."""
@@ -14,6 +14,7 @@ __all__ = [
   'table', 
   'tui_application', 
   'tui_component', 
-  'tui_preferences'
+  'tui_preferences', 
+  'tui_screen'
 ]
-__version__ = '0.9.20'
+__version__ = '0.9.43'
