@@ -1,6 +1,6 @@
 # _*_ coding: utf-8 _*_
 #
-# hspylib-clitt v0.9.20
+# hspylib-clitt v0.9.43
 #
 # Package: main.clitt.core.tui.mdashboard
 """Package initialization."""
@@ -8,6 +8,7 @@
 __all__ = [
   'dashboard_builder', 
   'dashboard_item', 
-  'mdashboard'
+  'mdashboard', 
+  'menu_dashboard'
 ]
-__version__ = '0.9.20'
+__version__ = '0.9.43'
