@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib
+   @project: HsPyLib
    @package: clitt.core.tui.mdashboard
       @file: dashboard_builder.py
    @created: Thu, 20 May 2021
@@ -10,22 +10,19 @@
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright 2023, HsPyLib team
 """
-from typing import Callable, List, Optional
-
 from clitt.core.icons.font_awesome.awesome import Awesome
 from clitt.core.tui.mdashboard.dashboard_item import DashboardItem
+from typing import Callable, List, Optional
 
 
 class DashboardBuilder:
-    """Dashboard builder.
-    """
+    """Dashboard builder."""
 
     @staticmethod
     class DashboardItemBuilder:
-        """Dashboard item builder.
-        """
+        """Dashboard item builder."""
 
         def __init__(self, parent: "DashboardBuilder"):
             self._parent = parent
