@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib
+   @project: HsPyLib
    @package: clitt.core.tui.mdashboard
       @file: dashboard_item.py
    @created: Thu, 20 May 2021
@@ -10,16 +10,14 @@
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright 2023, HsPyLib team
 """
-from typing import Callable, Optional
-
 from clitt.core.icons.font_awesome.awesome import Awesome
+from typing import Callable, Optional
 
 
 class DashboardItem:
-    """Represent a dashboard item.
-    """
+    """Represent a dashboard item."""
 
     def __init__(self, icon: Awesome = None, tooltip: str = None, on_trigger: Optional[Callable] = None):
         self.icon = icon
