@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib
+   @project: HsPyLib
    @package: clitt.core.tui.minput
       @file: access_type.py
    @created: Thu, 20 May 2021
@@ -10,15 +10,14 @@
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright 2023, HsPyLib team
 """
 
 from hspylib.core.enums.enumeration import Enumeration
 
 
 class AccessType(Enumeration):
-    """MenuInput input field access types.
-    """
+    """MenuInput input field access types."""
 
     # fmt: off
     NO_ACCESS   = "no-access"
