@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib
+   @project: HsPyLib
    @package: clitt.core.tui.minput
       @file: input_type.py
    @created: Thu, 20 May 2021
@@ -10,14 +10,13 @@
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright 2023, HsPyLib team
 """
 from hspylib.core.enums.enumeration import Enumeration
 
 
 class InputType(Enumeration):
-    """MenuInput input field types.
-    """
+    """MenuInput input field types."""
 
     # fmt: off
     TEXT        = "text"
