@@ -2,15 +2,15 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib
-   @package: hspylib.modules.cli.tui
+   @project: HsPyLib-Clitt
+   @package: clitt.core.tui
       @file: tui_application.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright 2023, HsPyLib team
 """
 
 from hspylib.core.metaclass.singleton import AbstractSingleton
@@ -31,7 +31,7 @@ class TUIApplication(Application, metaclass=AbstractSingleton):
         usage: str = None,
         epilog: str = None,
         resource_dir: str = None,
-        log_dir: str = None
+        log_dir: str = None,
     ):
         super().__init__(name, version, description, usage, epilog, resource_dir, log_dir)
         self._alt_screen = False
@@ -47,7 +47,6 @@ class TUIApplication(Application, metaclass=AbstractSingleton):
             self._alternate_screen()
 
     def _alternate_screen(self):
-        """Toggle switch to the alternate/main screen.
-        """
+        """Toggle switch to the alternate/main screen."""
         self._alt_screen = not self._alt_screen
         alternate_screen(self._alt_screen)
