@@ -2,24 +2,24 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib
-   @package: hspylib.modules.cli.tui
+   @project: HsPyLib-Clitt
+   @package: clitt.core.tui
       @file: tui_preferences.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright 2023, HsPyLib team
 """
 
-import os
+from clitt.core.icons.font_awesome.form_icons import FormIcons
+from clitt.core.icons.font_awesome.nav_icons import Awesome, NavIcons
 from hspylib.core.metaclass.singleton import Singleton
 from hspylib.core.tools.dict_tools import get_or_default_by_key
 from hspylib.modules.cli.vt100.vt_color import VtColor
 
-from clitt.core.icons.font_awesome.form_icons import FormIcons
-from clitt.core.icons.font_awesome.nav_icons import Awesome, NavIcons
+import os
 
 
 class TUIPreferences(metaclass=Singleton):
@@ -29,10 +29,10 @@ class TUIPreferences(metaclass=Singleton):
 
     def __init__(self, **kwargs):
         # fmt: off
-        self._max_rows: int             = \
-            get_or_default_by_key(kwargs, 'max_rows', 15)
+        self._max_rows: int       = \
+            get_or_default_by_key(kwargs, 'max_rows', 10)
         self._items_per_line: int       = \
-            get_or_default_by_key(kwargs, 'items_per_line', 5)
+            get_or_default_by_key(kwargs, 'items_per_line', 6)
         self._title_line_length: int    = \
             get_or_default_by_key(kwargs, 'title_line_length', 30)
         self._title_color: VtColor      = \
@@ -80,7 +80,7 @@ class TUIPreferences(metaclass=Singleton):
 
     @property
     def max_rows(self) -> int:
-        return max(5, self._max_rows)
+        return max(10, self._max_rows)
 
     @property
     def items_per_line(self) -> int:
